# Contributing to DABEST-Python


## Did you find a bug?
- Ensure the bug was not already reported by searching in [Issues](https://github.com/ACCLAB/DABEST-python/issues). Check that the bug hasn't been addressed in a closed issue.

- If the bug isn't being addressed, open a new issue using the Bug report template. Be sure to fill in the necessary information, and a [minimally reproducible code sample](https://matthewrocklin.com/blog/work/2018/02/28/minimal-bug-reports) demonstrating the expected behavior that is not occurring. 


## Did you write a patch that fixes a bug?
- Open a new GitHub [pull request](https://help.github.com/en/articles/about-pull-requests) (PR for short) with the patch.

- Create the PR into the development branch, which is indicated by `v{latest version number}-dev`.

- Clearly state the problem and solution in the PR description. Include the relevant [issue number](https://guides.github.com/features/issues/) if applicable.


## Do you intend to add a new feature or change an existing one?
- Suggest your change by opening an issue using the Feature request template.
- If the maintainers and the community are in favour, create a fork and start writing code.


DABEST is a community tool for estimation statistics and analysis. We look forward to more robust and more elegant data visualizations from you all!
